@@ -1,9 +1,9 @@
 package WWW::PAUSE::Simple;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-02-18'; # DATE
+our $DATE = '2020-09-18'; # DATE
 our $DIST = 'WWW-PAUSE-Simple'; # DIST
-our $VERSION = '0.447'; # VERSION
+our $VERSION = '0.448'; # VERSION
 
 use 5.010001;
 use strict;
@@ -492,13 +492,20 @@ _
         },
         newest_n => {
             schema => ['int*', min=>1],
-            summary => 'Only show this number of newest non-dev versions',
+            summary => 'Only show this number of newest versions',
             description => <<'_',
 
 Dev versions will be skipped.
 
 _
         },
+        include_nondev => {
+            schema => 'bool*',
+            default => 1,
+        },
+        include_dev => {
+            schema => 'bool*',
+        },
     },
 };
 sub list_dists {
@@ -516,6 +523,8 @@ sub list_dists {
     } elsif ($args{newest}) {
         $newest_n = 1;
     }
+    my $include_dev = $args{include_dev};
+    my $include_nondev = $args{include_nondev} // 1;
 
     my @dists;
     for my $file (@{$res->[2]}) {
@@ -523,17 +532,18 @@ sub list_dists {
             log_debug("Skipping %s: under a subdirectory", $file);
             next;
         }
-        my ($dist, $version, $is_dev) = _parse_release_filename($file);
+        my ($dist, $version0, $dev) = _parse_release_filename($file);
         unless (defined $dist) {
             log_debug("Skipping %s: doesn't match release regex", $file);
             next;
         }
-        next if $is_dev && $newest_n;
+        next if $newest_n && (($dev && !$include_dev) || (!$dev && !$include_nondev));
+        (my $version = $version0) =~ s/-TRIAL$/_001/;
         push @dists, {
             name => $dist,
             file => $file,
+            version0 => $version0,
             version => $version,
-            is_dev_version => $is_dev ? 1:0,
         };
     }
 
@@ -582,19 +592,29 @@ $SPEC{delete_old_releases} = {
     summary => 'Delete older versions of distributions',
     description => <<'_',
 
-Developer releases will not be deleted.
+Currently does not look for releases in subdirectories.
 
-To delete developer releases, you can use `delete_files` (rm), e.g. from the
-command line:
+By default does not include developer (trial) releases. To include that, use
+`--include-dev`.
 
-    % pause rm 'My-Module-*TRIAL*'; # delete a dist's trial releases
-    % pause rm '*TRIAL*' '*_*'; # delete all files containing TRIAL or underscore
+To only cleanup developer deleases, you can use `--exclude-dev` and
+`--include-nondev`.
 
 _
     args => {
         %common_args,
         %detail_l_arg,
         %protect_files_arg,
+        include_nondev => {
+            summary => 'Whether to include cleaning up non-dev releases',
+            schema => 'bool*',
+            default => 1,
+        },
+        include_dev => {
+            summary => 'Whether to include cleaning up non-dev releases',
+            schema => 'bool*',
+            default => 0,
+        },
         num_keep => {
             schema => ['int*', min=>1],
             default => 1,
@@ -613,7 +633,7 @@ _
 sub delete_old_releases {
     my %args = @_;
 
-    my $res = list_dists(_common_args(\%args), newest_n=>$args{num_keep}//1);
+    my $res = list_dists(_common_args(\%args), newest_n=>$args{num_keep}//1, include_dev=>$args{include_dev}, include_nondev=>$args{include_nondev});
     return [500, "Can't list dists: $res->[0] - $res->[1]"] if $res->[0] != 200;
     my $old_files = $res->[3]{'func.old_files'};
 
@@ -937,7 +957,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.447 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2020-02-18.
+This document describes version 0.448 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2020-09-18.
 
 =head1 SYNOPSIS
 
@@ -1033,13 +1053,13 @@ Usage:
 
 Delete older versions of distributions.
 
-Developer releases will not be deleted.
+Currently does not look for releases in subdirectories.
 
-To delete developer releases, you can use C<delete_files> (rm), e.g. from the
-command line:
+By default does not include developer (trial) releases. To include that, use
+C<--include-dev>.
 
- % pause rm 'My-Module-*TRIAL*'; # delete a dist's trial releases
- % pause rm '*TRIAL*' '*_*'; # delete all files containing TRIAL or underscore
+To only cleanup developer deleases, you can use C<--exclude-dev> and
+C<--include-nondev>.
 
 This function is not exported by default, but exportable.
 
@@ -1054,6 +1074,14 @@ Arguments ('*' denotes required arguments):
 
 Whether to return detailed records.
 
+=item * B<include_dev> => I<bool> (default: 0)
+
+Whether to include cleaning up non-dev releases.
+
+=item * B<include_nondev> => I<bool> (default: 1)
+
+Whether to include cleaning up non-dev releases.
+
 =item * B<num_keep> => I<int> (default: 1)
 
 Number of new versions (including newest) to keep.
@@ -1134,6 +1162,10 @@ Arguments ('*' denotes required arguments):
 
 Whether to return detailed records.
 
+=item * B<include_dev> => I<bool>
+
+=item * B<include_nondev> => I<bool> (default: 1)
+
 =item * B<newest> => I<bool>
 
 Only show newest non-dev version.
@@ -1142,7 +1174,7 @@ Dev versions will be skipped.
 
 =item * B<newest_n> => I<int>
 
-Only show this number of newest non-dev versions.
+Only show this number of newest versions.
 
 Dev versions will be skipped.
 
